@@ -67,27 +67,21 @@ class QQuickMaterialStyle : public QQuickStyleAttached
     Q_PROPERTY(QColor primaryColor READ primaryColor NOTIFY primaryChanged FINAL) // TODO: remove?
     Q_PROPERTY(QColor accentColor READ accentColor NOTIFY accentChanged FINAL) // TODO: remove?
     Q_PROPERTY(QColor backgroundColor READ backgroundColor NOTIFY backgroundChanged FINAL)
-    Q_PROPERTY(QColor primaryTextColor READ primaryTextColor NOTIFY foregroundChanged FINAL)  // TODO: rename to foregroundColor()?
+    Q_PROPERTY(QColor primaryTextColor READ primaryTextColor NOTIFY paletteChanged FINAL)
     Q_PROPERTY(QColor primaryHighlightedTextColor READ primaryHighlightedTextColor NOTIFY paletteChanged FINAL)
     Q_PROPERTY(QColor secondaryTextColor READ secondaryTextColor NOTIFY paletteChanged FINAL)
     Q_PROPERTY(QColor hintTextColor READ hintTextColor NOTIFY paletteChanged FINAL)
     Q_PROPERTY(QColor textSelectionColor READ textSelectionColor NOTIFY paletteChanged FINAL)
     Q_PROPERTY(QColor dropShadowColor READ dropShadowColor NOTIFY paletteChanged FINAL)
     Q_PROPERTY(QColor dividerColor READ dividerColor NOTIFY paletteChanged FINAL)
+    Q_PROPERTY(QColor iconColor READ iconColor NOTIFY paletteChanged FINAL)
+    Q_PROPERTY(QColor iconDisabledColor READ iconDisabledColor NOTIFY paletteChanged FINAL)
     Q_PROPERTY(QColor buttonColor READ buttonColor NOTIFY paletteChanged FINAL)
-    Q_PROPERTY(QColor buttonHoverColor READ buttonHoverColor NOTIFY paletteChanged FINAL)
-    Q_PROPERTY(QColor buttonPressColor READ buttonPressColor NOTIFY paletteChanged FINAL)
     Q_PROPERTY(QColor buttonDisabledColor READ buttonDisabledColor NOTIFY paletteChanged FINAL)
     Q_PROPERTY(QColor highlightedButtonColor READ highlightedButtonColor NOTIFY paletteChanged FINAL)
-    Q_PROPERTY(QColor highlightedButtonHoverColor READ highlightedButtonHoverColor NOTIFY paletteChanged FINAL)
-    Q_PROPERTY(QColor highlightedButtonPressColor READ highlightedButtonPressColor NOTIFY paletteChanged FINAL)
-    Q_PROPERTY(QColor swipeDelegateColor READ swipeDelegateColor NOTIFY paletteChanged FINAL)
-    Q_PROPERTY(QColor swipeDelegateHoverColor READ swipeDelegateHoverColor NOTIFY paletteChanged FINAL)
-    Q_PROPERTY(QColor swipeDelegatePressColor READ swipeDelegatePressColor NOTIFY paletteChanged FINAL)
-    Q_PROPERTY(QColor swipeDelegateDisabledColor READ swipeDelegateDisabledColor NOTIFY paletteChanged FINAL)
     Q_PROPERTY(QColor frameColor READ frameColor NOTIFY paletteChanged FINAL)
-    Q_PROPERTY(QColor checkBoxUncheckedRippleColor READ checkBoxUncheckedRippleColor NOTIFY paletteChanged FINAL)
-    Q_PROPERTY(QColor checkBoxCheckedRippleColor READ checkBoxCheckedRippleColor NOTIFY paletteChanged FINAL)
+    Q_PROPERTY(QColor rippleColor READ rippleColor NOTIFY paletteChanged FINAL)
+    Q_PROPERTY(QColor highlightedRippleColor READ highlightedRippleColor NOTIFY paletteChanged FINAL)
     Q_PROPERTY(QColor switchUncheckedTrackColor READ switchUncheckedTrackColor NOTIFY paletteChanged FINAL)
     Q_PROPERTY(QColor switchCheckedTrackColor READ switchCheckedTrackColor NOTIFY paletteChanged FINAL)
     Q_PROPERTY(QColor switchUncheckedHandleColor READ switchUncheckedHandleColor NOTIFY paletteChanged FINAL)
@@ -95,6 +89,7 @@ class QQuickMaterialStyle : public QQuickStyleAttached
     Q_PROPERTY(QColor switchDisabledTrackColor READ switchDisabledTrackColor NOTIFY paletteChanged FINAL)
     Q_PROPERTY(QColor switchDisabledHandleColor READ switchDisabledHandleColor NOTIFY paletteChanged FINAL)
     Q_PROPERTY(QColor scrollBarColor READ scrollBarColor NOTIFY paletteChanged FINAL)
+    Q_PROPERTY(QColor scrollBarHoveredColor READ scrollBarHoveredColor NOTIFY paletteChanged FINAL)
     Q_PROPERTY(QColor scrollBarPressedColor READ scrollBarPressedColor NOTIFY paletteChanged FINAL)
     Q_PROPERTY(QColor dialogColor READ dialogColor NOTIFY paletteChanged FINAL)
     Q_PROPERTY(QColor backgroundDimColor READ backgroundDimColor NOTIFY paletteChanged FINAL)
@@ -107,7 +102,8 @@ class QQuickMaterialStyle : public QQuickStyleAttached
 public:
     enum Theme {
         Light,
-        Dark
+        Dark,
+        System
     };
 
     enum Color {
@@ -201,21 +197,15 @@ public:
     QColor textSelectionColor() const;
     QColor dropShadowColor() const;
     QColor dividerColor() const;
+    QColor iconColor() const;
+    QColor iconDisabledColor() const;
     QColor buttonColor() const;
-    QColor buttonHoverColor() const;
-    QColor buttonPressColor() const;
     QColor buttonDisabledColor() const;
     QColor highlightedButtonColor() const;
-    QColor highlightedButtonHoverColor() const;
-    QColor highlightedButtonPressColor() const;
     QColor highlightedButtonDisabledColor() const;
-    QColor swipeDelegateColor() const;
-    QColor swipeDelegateHoverColor() const;
-    QColor swipeDelegatePressColor() const;
-    QColor swipeDelegateDisabledColor() const;
     QColor frameColor() const;
-    QColor checkBoxUncheckedRippleColor() const;
-    QColor checkBoxCheckedRippleColor() const;
+    QColor rippleColor() const;
+    QColor highlightedRippleColor() const;
     QColor switchUncheckedTrackColor() const;
     QColor switchCheckedTrackColor() const;
     QColor switchUncheckedHandleColor() const;
@@ -223,6 +213,7 @@ public:
     QColor switchDisabledTrackColor() const;
     QColor switchDisabledHandleColor() const;
     QColor scrollBarColor() const;
+    QColor scrollBarHoveredColor() const;
     QColor scrollBarPressedColor() const;
     QColor dialogColor() const;
     QColor backgroundDimColor() const;
@@ -254,7 +245,7 @@ private:
 
     QColor backgroundColor(Shade shade) const;
     QColor accentColor(Shade shade) const;
-    QColor buttonColor(bool highlighted, bool pressed, bool hover) const;
+    QColor buttonColor(bool highlighted) const;
     Shade themeShade() const;
 
     // These reflect whether a color value was explicitly set on the specific
