@@ -35,16 +35,38 @@
 ****************************************************************************/
 
 #include "qquickstyleattached_p.h"
+#include "qquickstyle_p.h"
 
 #include <QtCore/qfile.h>
 #include <QtCore/qsettings.h>
 #include <QtCore/qfileselector.h>
+#include <QtGui/qcolor.h>
+#include <QtGui/qpalette.h>
+#include <QtGui/private/qguiapplication_p.h>
+#include <QtGui/qpa/qplatformtheme.h>
 #include <QtQuick/qquickwindow.h>
 #include <QtQuick/private/qquickitem_p.h>
 #include <QtQuickTemplates2/private/qquickpopup_p.h>
 
 QT_BEGIN_NAMESPACE
 
+static bool isDarkSystemTheme()
+{
+    if (const QPlatformTheme *theme = QGuiApplicationPrivate::platformTheme()) {
+        if (const QPalette *systemPalette = theme->palette(QPlatformTheme::SystemPalette)) {
+            const QColor textColor = systemPalette->color(QPalette::WindowText);
+            return textColor.red() > 128 && textColor.blue() > 128 && textColor.green() > 128;
+        }
+    }
+    return false;
+}
+
+Q_QUICKCONTROLS2_PRIVATE_EXPORT bool qt_is_dark_system_theme()
+{
+    static bool dark = isDarkSystemTheme();
+    return dark;
+}
+
 static QQuickStyleAttached *attachedStyle(const QMetaObject *type, QObject *object, bool create = false)
 {
     if (!object)
@@ -146,18 +168,6 @@ static QList<QQuickStyleAttached *> findChildStyles(const QMetaObject *type, QOb
     return children;
 }
 
-static QString resolveConfigFile()
-{
-    QString filePath = QFile::decodeName(qgetenv("QT_QUICK_CONTROLS_CONF"));
-    if (!QFile::exists(filePath)) {
-        if (!filePath.isEmpty())
-            qWarning("QT_QUICK_CONTROLS_CONF=%s: No such file", qPrintable(filePath));
-
-        filePath = QStringLiteral(":/qtquickcontrols2.conf");
-    }
-    return filePath;
-}
-
 QQuickStyleAttached::QQuickStyleAttached(QObject *parent) : QObject(parent)
 {
     QQuickItem *item = qobject_cast<QQuickItem *>(parent);
@@ -187,7 +197,7 @@ QQuickStyleAttached::~QQuickStyleAttached()
 QSharedPointer<QSettings> QQuickStyleAttached::settings(const QString &group)
 {
 #ifndef QT_NO_SETTINGS
-    static const QString filePath = resolveConfigFile();
+    const QString filePath = QQuickStylePrivate::configFilePath();
     if (QFile::exists(filePath)) {
         QFileSelector selector;
         QSettings *settings = new QSettings(selector.select(filePath), QSettings::IniFormat);
