@@ -50,14 +50,14 @@ QT_BEGIN_NAMESPACE
     \inqmlmodule QtQuick.Controls
     \since 5.7
     \ingroup qtquickcontrols2-indicators
-    \brief A non-interactive scroll indicator control.
+    \brief Vertical or horizontal non-interactive scroll indicator.
+
+    \image qtquickcontrols2-scrollindicator.gif
 
     ScrollIndicator is a non-interactive indicator that indicates the current scroll
     position. A scroll indicator can be either \l vertical or \l horizontal, and can
     be attached to any \l Flickable, such as \l ListView and \l GridView.
 
-    \image qtquickcontrols2-scrollindicator.png
-
     \code
     Flickable {
         // ...
@@ -65,9 +65,12 @@ QT_BEGIN_NAMESPACE
     }
     \endcode
 
+    \section1 Attaching ScrollIndicator to a Flickable
+
     \note When ScrollIndicator is attached \l {ScrollIndicator::vertical}{vertically}
     or \l {ScrollIndicator::horizontal}{horizontally} to a Flickable, its geometry and
     the following properties are automatically set and updated as appropriate:
+
     \list
     \li \l orientation
     \li \l position
@@ -75,6 +78,31 @@ QT_BEGIN_NAMESPACE
     \li \l active
     \endlist
 
+    An attached ScrollIndicator re-parents itself to the target Flickable. A vertically
+    attached ScrollIndicator resizes itself to the height of the Flickable, and positions
+    itself to either side of it based on the \l {Control::mirrored}{layout direction}.
+    A horizontally attached ScrollIndicator resizes itself to the width of the Flickable,
+    and positions itself to the bottom. The automatic geometry management can be disabled
+    by specifying another parent for the attached ScrollIndicator. This can be useful, for
+    example, if the ScrollIndicator should be placed outside a clipping Flickable. This is
+    demonstrated by the following example:
+
+    \code
+    Flickable {
+        id: flickable
+        clip: true
+        // ...
+        ScrollIndicator.vertical: ScrollIndicator {
+            parent: flickable.parent
+            anchors.top: flickable.top
+            anchors.left: flickable.right
+            anchors.bottom: flickable.bottom
+        }
+    }
+    \endcode
+
+    \section1 Binding the Active State of Horizontal and Vertical Scroll Indicators
+
     Horizontal and vertical scroll indicators do not share the \l active state with
     each other by default. In order to keep both indicators visible whilst scrolling
     to either direction, establish a two-way binding between the active states as
@@ -82,6 +110,19 @@ QT_BEGIN_NAMESPACE
 
     \snippet qtquickcontrols2-scrollindicator-active.qml 1
 
+    \section1 Non-attached Scroll Indicators
+
+    It is possible to create an instance of ScrollIndicator without using the
+    attached property API. This is useful when the behavior of the attached
+    scoll indicator is not sufficient or a \l Flickable is not in use. In the
+    following example, horizontal and vertical scroll indicators are used to
+    indicate how far the user has scrolled over the text (using \l MouseArea
+    instead of \l Flickable):
+
+    \snippet qtquickcontrols2-scrollindicator-non-attached.qml 1
+
+    \image qtquickcontrols2-scrollindicator-non-attached.png
+
     \sa ScrollBar, {Customizing ScrollIndicator}, {Indicator Controls}
 */
 
@@ -143,6 +184,9 @@ QQuickScrollIndicatorAttached *QQuickScrollIndicator::qmlAttachedProperties(QObj
     This property holds the size of the indicator, scaled to \c {0.0 - 1.0}.
 
     \sa {Flickable::visibleArea.heightRatio}{Flickable::visibleArea}
+
+    This property is automatically set when the scroll indicator is
+    \l {Attaching ScrollIndicator to a Flickable}{attached to a flickable}.
 */
 qreal QQuickScrollIndicator::size() const
 {
@@ -167,6 +211,9 @@ void QQuickScrollIndicator::setSize(qreal size)
 
     This property holds the position of the indicator, scaled to \c {0.0 - 1.0}.
 
+    This property is automatically set when the scroll indicator is
+    \l {Attaching ScrollIndicator to a Flickable}{attached to a flickable}.
+
     \sa {Flickable::visibleArea.yPosition}{Flickable::visibleArea}
 */
 qreal QQuickScrollIndicator::position() const
@@ -192,6 +239,12 @@ void QQuickScrollIndicator::setPosition(qreal position)
 
     This property holds whether the indicator is active, that is, when the
     attached Flickable is \l {Flickable::moving}{moving}.
+
+    It is possible to keep \l {Binding the Active State of Horizontal and Vertical Scroll Indicators}
+    {both horizontal and vertical indicators visible} while scrolling in either direction.
+
+    This property is automatically set when the scroll indicator is
+    \l {Attaching ScrollIndicator to a Flickable}{attached to a flickable}.
 */
 bool QQuickScrollIndicator::isActive() const
 {
@@ -217,6 +270,9 @@ void QQuickScrollIndicator::setActive(bool active)
     Possible values:
     \value Qt.Horizontal Horizontal
     \value Qt.Vertical Vertical (default)
+
+    This property is automatically set when the scroll indicator is
+    \l {Attaching ScrollIndicator to a Flickable}{attached to a flickable}.
 */
 Qt::Orientation QQuickScrollIndicator::orientation() const
 {
@@ -247,7 +303,7 @@ public:
     void layoutHorizontal(bool move = true);
     void layoutVertical(bool move = true);
 
-    void itemGeometryChanged(QQuickItem *item, const QRectF &newGeometry, const QRectF &oldGeometry) override;
+    void itemGeometryChanged(QQuickItem *item, QQuickGeometryChange change, const QRectF &diff) override;
     void itemDestroyed(QQuickItem *item) override;
 
     QQuickFlickable *flickable;
@@ -268,6 +324,8 @@ void QQuickScrollIndicatorAttachedPrivate::activateVertical()
 void QQuickScrollIndicatorAttachedPrivate::layoutHorizontal(bool move)
 {
     Q_ASSERT(horizontal && flickable);
+    if (horizontal->parentItem() != flickable)
+        return;
     horizontal->setWidth(flickable->width());
     if (move)
         horizontal->setY(flickable->height() - horizontal->height());
@@ -276,21 +334,31 @@ void QQuickScrollIndicatorAttachedPrivate::layoutHorizontal(bool move)
 void QQuickScrollIndicatorAttachedPrivate::layoutVertical(bool move)
 {
     Q_ASSERT(vertical && flickable);
+    if (vertical->parentItem() != flickable)
+        return;
     vertical->setHeight(flickable->height());
     if (move && !QQuickItemPrivate::get(vertical)->isMirrored())
         vertical->setX(flickable->width() - vertical->width());
 }
 
-void QQuickScrollIndicatorAttachedPrivate::itemGeometryChanged(QQuickItem *item, const QRectF &newGeometry, const QRectF &oldGeometry)
+void QQuickScrollIndicatorAttachedPrivate::itemGeometryChanged(QQuickItem *item, QQuickGeometryChange change, const QRectF &diff)
 {
     Q_UNUSED(item);
-    Q_UNUSED(newGeometry);
+    Q_UNUSED(change);
     if (horizontal && horizontal->height() > 0) {
-        bool move = qFuzzyIsNull(horizontal->y()) || qFuzzyCompare(horizontal->y(), oldGeometry.height() - horizontal->height());
+#ifdef QT_QUICK_NEW_GEOMETRY_CHANGED_HANDLING // TODO: correct/rename diff to oldGeometry
+        bool move = qFuzzyIsNull(horizontal->y()) || qFuzzyCompare(horizontal->y(), diff.height() - horizontal->height());
+#else
+        bool move = qFuzzyIsNull(horizontal->y()) || qFuzzyCompare(horizontal->y(), item->height() - diff.height() - horizontal->height());
+#endif
         layoutHorizontal(move);
     }
     if (vertical && vertical->width() > 0) {
-        bool move = qFuzzyIsNull(vertical->x()) || qFuzzyCompare(vertical->x(), oldGeometry.width() - vertical->width());
+#ifdef QT_QUICK_NEW_GEOMETRY_CHANGED_HANDLING // TODO: correct/rename diff to oldGeometry
+        bool move = qFuzzyIsNull(vertical->x()) || qFuzzyCompare(vertical->x(), diff.width() - vertical->width());
+#else
+        bool move = qFuzzyIsNull(vertical->x()) || qFuzzyCompare(vertical->x(), item->width() - diff.width() - vertical->width());
+#endif
         layoutVertical(move);
     }
 }
@@ -309,7 +377,7 @@ QQuickScrollIndicatorAttached::QQuickScrollIndicatorAttached(QQuickFlickable *fl
     Q_D(QQuickScrollIndicatorAttached);
     if (flickable) {
         QQuickItemPrivate *p = QQuickItemPrivate::get(flickable);
-        p->updateOrAddGeometryChangeListener(d, QQuickItemPrivate::SizeChange);
+        p->updateOrAddGeometryChangeListener(d, QQuickGeometryChange::Size);
     }
 }
 
@@ -336,6 +404,8 @@ QQuickScrollIndicatorAttached::~QQuickScrollIndicatorAttached()
         ScrollIndicator.horizontal: ScrollIndicator { }
     }
     \endcode
+
+    \sa {Attaching ScrollIndicator to a Flickable}
 */
 QQuickScrollIndicator *QQuickScrollIndicatorAttached::horizontal() const
 {
@@ -392,6 +462,8 @@ void QQuickScrollIndicatorAttached::setHorizontal(QQuickScrollIndicator *horizon
         ScrollIndicator.vertical: ScrollIndicator { }
     }
     \endcode
+
+    \sa {Attaching ScrollIndicator to a Flickable}
 */
 QQuickScrollIndicator *QQuickScrollIndicatorAttached::vertical() const
 {
